# EInvoiceStatus

e-invoice status 

## Enum

* `PROCESSING` (value: `'Processing'`)

* `SUCCESS` (value: `'Success'`)

* `FAILED` (value: `'Failed'`)

* `SKIPPED` (value: `'Skipped'`)

* `CONDITIONALSUCCESS` (value: `'ConditionalSuccess'`)

* `APPROVEDBYAUTHORITY` (value: `'ApprovedByAuthority'`)

* `REJECTED` (value: `'Rejected'`)

* `CANCELPROCESSING` (value: `'CancelProcessing'`)

* `CANCELLED` (value: `'Cancelled'`)

* `CANCELFAILED` (value: `'CancelFailed'`)

* `GENERATED` (value: `'Generated'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


